[![Build Status](https://travis-ci.org/grburgess/pychangcooper.svg?branch=master)](https://travis-ci.org/grburgess/pychangcooper)
[![codecov](https://codecov.io/gh/grburgess/pychangcooper/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/pychangcooper)
[![Maintainability](https://api.codeclimate.com/v1/badges/d50bfcd029c78df0c8aa/maintainability)](https://codeclimate.com/github/grburgess/pychangcooper/maintainability)
[![Documentation Status](https://readthedocs.org/projects/pychangcooper/badge/?version=latest)](http://pychangcooper.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1163533.svg)](https://doi.org/10.5281/zenodo.1163533)


# pychangcooper
![alt text](https://raw.githubusercontent.com/grburgess/pychangcooper/master/logo.png)

A python solver for Fokker-Planck equations via the Chang and Cooper method
